@@ -1,7 +1,7 @@
 package App::BencherUtils;
 
-our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-03-10'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,8 +47,8 @@ sub _clean {
 
 sub _json {
     state $json = do {
-        require JSON;
-        my $json = JSON->new;
+        require JSON::MaybeXS;
+        my $json = JSON::MaybeXS->new;
         $json->convert_blessed(1);
     };
     $json;
@@ -543,7 +543,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.09 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-22.
+This document describes version 0.10 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-03-10.
 
 =head1 SYNOPSIS
 
@@ -577,7 +577,7 @@ with the following name pattern:
  <NAME>-<SUBNAME>.<yyyy>-<mm>-<dd>T<HH>-<MM>-<SS>.json
  <NAME>-<SUBNAME>.module_startup.<yyyy>-<mm>-<dd>T<HH>-<MM>-<SS>.json
 
-This function is not exportable.
+This function is not exported.
 
 This function supports dry-run operation.
 
@@ -650,7 +650,7 @@ Return value:  (any)
 
 Shortcut for bencher-all --no-lib --lib lib.
 
-This function is not exportable.
+This function is not exported.
 
 This function supports dry-run operation.
 
@@ -715,7 +715,7 @@ Return value:  (any)
 
 List results in results directory.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
